@@ -11,27 +11,24 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "lnf_integration.h"
 #include "screenlocker_interface.h"
 
-#include <KAboutData>
 #include <KConfigLoader>
 #include <KConfigPropertyMap>
 #include <KGlobalAccel>
 #include <KLocalizedString>
 #include <KPluginFactory>
 
-#include <KPackage/PackageLoader>
-
-#include <QVector>
+#include <QList>
 
 K_PLUGIN_FACTORY_WITH_JSON(ScreenLockerKcmFactory, "kcm_screenlocker.json", registerPlugin<ScreenLockerKcm>(); registerPlugin<KScreenLockerData>();)
 
-ScreenLockerKcm::ScreenLockerKcm(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KQuickAddons::ManagedConfigModule(parent, data, args)
+ScreenLockerKcm::ScreenLockerKcm(QObject *parent, const KPluginMetaData &data)
+    : KQuickManagedConfigModule(parent, data)
     , m_appearanceSettings(new AppearanceSettings(this))
 {
     registerSettings(&KScreenSaverSettings::getInstance());
 
     constexpr const char *url = "org.kde.private.kcms.screenlocker";
-    qRegisterMetaType<QVector<WallpaperInfo>>("QVector<WallpaperInfo>");
+    qRegisterMetaType<QList<WallpaperInfo>>("QList<WallpaperInfo>");
     qmlRegisterAnonymousType<KScreenSaverSettings>(url, 1);
     qmlRegisterAnonymousType<WallpaperInfo>(url, 1);
     qmlRegisterAnonymousType<ScreenLocker::WallpaperIntegration>(url, 1);
@@ -51,7 +48,7 @@ ScreenLockerKcm::ScreenLockerKcm(QObject *parent, const KPluginMetaData &data, c
 
 void ScreenLockerKcm::load()
 {
-    ManagedConfigModule::load();
+    KQuickManagedConfigModule::load();
     m_appearanceSettings->load();
 
     updateState();
@@ -59,7 +56,7 @@ void ScreenLockerKcm::load()
 
 void ScreenLockerKcm::save()
 {
-    ManagedConfigModule::save();
+    KQuickManagedConfigModule::save();
     m_appearanceSettings->save();
 
     // reconfigure through DBus
@@ -72,7 +69,7 @@ void ScreenLockerKcm::save()
 
 void ScreenLockerKcm::defaults()
 {
-    ManagedConfigModule::defaults();
+    KQuickManagedConfigModule::defaults();
     m_appearanceSettings->defaults();
 
     updateState();
@@ -143,3 +140,5 @@ ScreenLocker::WallpaperIntegration *ScreenLockerKcm::wallpaperIntegration() cons
 }
 
 #include "kcm.moc"
+
+#include "moc_kcm.cpp"
